######
Plots
######


.. autosummary::
    :toctree: _source/

    pypsa.Network.plot
    pypsa.Network.iplot
    pypsa.Network.explore
    pypsa.plot.add_legend_circles
    pypsa.plot.add_legend_patches
    pypsa.plot.add_legend_lines